package com.ippon.borestop.activity.domain;

import static com.ippon.borestop.activity.domain.IdeasFixture.*;
import static com.ippon.borestop.activity.domain.PartnersFixture.*;
import static org.assertj.core.api.Assertions.*;

import com.ippon.borestop.common.domain.error.MissingMandatoryValueException;
import org.junit.jupiter.api.Test;

class ActivityUnitTest {

  @Test
  void shouldNotBuildWithoutIdea() {
    assertThatThrownBy(() -> new Activity(null, partners()))
      .isExactlyInstanceOf(MissingMandatoryValueException.class)
      .hasMessageContaining("idea");
  }

  @Test
  void shouldNotBuildWithoutPartners() {
    assertThatThrownBy(() -> new Activity(idea(), null))
      .isExactlyInstanceOf(MissingMandatoryValueException.class)
      .hasMessageContaining("partners");
  }

  @Test
  void shouldBuildActivityWithoutMatchingPartners() {
    Activity activity = new Activity(idea(), emptyPartners());

    assertThat(activity.getLabel()).isEqualTo(label());
    assertThat(activity.getPartners()).isEmpty();
  }

  @Test
  void shouldBuildActivityWithThreePartnersInCategory() {
    Activity activity = new Activity(idea(), threePartners());

    assertThat(activity.getLabel()).isEqualTo(label());
    assertThat(activity.getPartners())
      .usingFieldByFieldElementComparator()
      .containsExactly(firstPartner(), secondPartner(), thirdPartner());
  }

  private Partners partners() {
    return threePartners();
  }

  private Partners emptyPartners() {
    return Partners.empty();
  }
}
